@@ -1,6 +1,6 @@
-## This file is part of the CITAN library.
+## This file is part of the CITAN package for R
 ##
-## Copyright 2011 Marek Gagolewski <gagolews@ibspan.waw.pl>
+## Copyright 2011-2014 Marek Gagolewski
 ##
 ##
 ## CITAN is free software: you can redistribute it and/or modify
@@ -16,14 +16,9 @@
 ## You should have received a copy of the GNU Lesser General Public License
 ## along with CITAN. If not, see <http://www.gnu.org/licenses/>.
 
-#' @include biblio.internal.R
-NA
-
-
-
 
 #' Retrieves basic information on given authors.
-#' 
+#'
 #' @title Retrieve author information
 #' @param conn a connection object as produced by \code{\link{lbsConnect}}.
 #' @param idAuthors a numeric or integer vector with author identifiers (see column \code{IdAuthor} in the table \code{Biblio_Authors}).
@@ -32,6 +27,7 @@ NA
 #' \itemize{
 #' \item \code{IdAuthor} --- numeric; author's identifier in the table \code{Biblio_Authors},
 #' \item \code{Name} --- character; author's name.
+#' \item \code{AuthorGroup} --- character; author group (used to merge author records).
 #' }
 #' @examples
 #' \dontrun{
@@ -42,40 +38,40 @@ NA
 #' ## ...}
 #' @seealso \code{\link{lbsSearchAuthors}}, \code{\link{lbsSearchDocuments}},
 #' \code{\link{lbsGetInfoDocuments}},\cr
-#' \code{\link{as.character.authorinfo}}, \code{\link{print.authorinfo}}, 
+#' \code{\link{as.character.authorinfo}}, \code{\link{print.authorinfo}},
 #' @export
 lbsGetInfoAuthors <- function(conn, idAuthors)
 {
-	CITAN:::.lbsCheckConnection(conn); # will stop on invalid/dead connection
+   .lbsCheckConnection(conn); # will stop on invalid/dead connection
 
-		
-	if (is.null(idAuthors) || (class(idAuthors) != "numeric" && class(idAuthors) != "integer"))
-		stop("'idAuthors' must be a nonempty numeric vector.");
-		
-	query <- sprintf("SELECT IdAuthor, Name FROM Biblio_Authors WHERE IdAuthor IN (%s)",
-			paste(idAuthors, collapse=","));
-			
-	res <- dbGetQuery(conn, query);
-	n <- nrow(res);
-	out <- list();
-	length(out) <- n;
-	
-	
-	
-	if (n < 1) return(NULL);
-	
-	for (i in 1:n)
-	{
-		out[[i]] <- list(IdAuthor=res[i,1], Name=res[i,2]);
-		class(out[[i]]) <- "authorinfo";
-	}
 
-	return(out);
+   if (is.null(idAuthors) || (class(idAuthors) != "numeric" && class(idAuthors) != "integer"))
+      stop("'idAuthors' must be a nonempty numeric vector.");
+
+   query <- sprintf("SELECT IdAuthor, Name, AuthorGroup FROM Biblio_Authors WHERE IdAuthor IN (%s)",
+         paste(idAuthors, collapse=","));
+
+   res <- dbGetQuery(conn, query);
+   n <- nrow(res);
+   out <- list();
+   length(out) <- n;
+
+
+
+   if (n < 1) return(NULL);
+
+   for (i in 1:n)
+   {
+      out[[i]] <- list(IdAuthor=res[i,1], Name=res[i,2], AuthorGroup=res[i,3]);
+      class(out[[i]]) <- "authorinfo";
+   }
+
+   return(out);
 }
 
 
 #' Retrieves information on given documents.
-#' 
+#'
 #' @title Retrieve document information
 #' @param conn a connection object as produced by \code{\link{lbsConnect}}.
 #' @param idDocuments a numeric or integer vector with document identifiers (see column \code{IdDocument} in the table \code{Biblio_Documents}).
@@ -86,7 +82,7 @@ lbsGetInfoAuthors <- function(conn, idAuthors)
 #' \item \code{Authors} --- list of \code{authorinfo} objects (see e.g. \code{\link{as.character.authorinfo}}).
 #' \item \code{Title} --- title of the document,
 #' \item \code{BibEntry} --- bibliographic entry,
-#' \item \code{UniqueId} --- unique character identifier,
+#' \item \code{AlternativeId} --- unique character identifier,
 #' \item \code{Pages} --- number of pages,
 #' \item \code{Citations} --- number of citations,
 #' \item \code{Year} --- publication year,
@@ -106,74 +102,74 @@ lbsGetInfoAuthors <- function(conn, idAuthors)
 #' @export
 lbsGetInfoDocuments <- function(conn, idDocuments)
 {
-	CITAN:::.lbsCheckConnection(conn); # will stop on invalid/dead connection
-
-		
-	if (is.null(idDocuments) || (class(idDocuments) != "numeric" && class(idDocuments) != "integer"))
-		stop("'idDocuments' must be a nonempty numeric vector.");
-		
-	idDocuments_str <- paste(idDocuments, collapse=",");
-	query <- sprintf("SELECT IdDocument, Title, BibEntry, UniqueId, Pages, Citations, Year, Type
-			FROM Biblio_Documents WHERE IdDocument IN (%s) ORDER BY IdDocument",
-			idDocuments_str);
-			
-	res <- dbGetQuery(conn, query);
-	n <- nrow(res);
-	out <- list();
-	length(out) <- n;
-
-	
-	if (n < 1) return(NULL);
-	
-	query2 <- sprintf("SELECT DISTINCT IdDocument, Biblio_Authors.IdAuthor, Name FROM
-		Biblio_AuthorsDocuments
-		JOIN Biblio_Authors ON Biblio_Authors.IdAuthor=Biblio_AuthorsDocuments.IdAuthor
-		WHERE IdDocument IN (%s) ORDER BY IdDocument",
-		idDocuments_str);
-	res2 <- dbGetQuery(conn, query2);
-	stopifnot(nrow(res2) >= 1);
-	
-
-	i <- 1;
-	k <- 1;
-	m <- nrow(res2);
-	
-	while (i <= m)
-	{
-		stopifnot(res2$IdDocument[i] == res$IdDocument[k]);
-		
-		j <- i+1;
-		while (j<=m && res2$IdDocument[i] == res2$IdDocument[j])
-			j <- j+1;
-			
-		authors <- list();
-		length(authors) <- j-i;
-		for (u in i:(j-1))
-		{
-			authors[[u-i+1]] <- list(IdAuthor=res2[u,2], Name=res2[u,3]);
-			class(authors[[u-i+1]]) <- "authorinfo";
-		}
-		
-		doc <- list(IdDocument=res[k,1], Authors=authors, Title=res[k,2], BibEntry=res[k,3],
-			UniqueId=res[k,4], Pages=res[k,5], Citations=res[k,6],
-			Year=res[k,7], Type=CITAN:::.lbs_DocumentType_ShortToFull(res[k,8]));
-			
-		class(doc) <- "docinfo";
-	
-		out[[k]] <- doc;
-		
-		
-		i <- j;
-		k <- k+1;
-	}
-	stopifnot(k-1 == n);
+   .lbsCheckConnection(conn); # will stop on invalid/dead connection
 
 
-	return(out);
+   if (is.null(idDocuments) || (class(idDocuments) != "numeric" && class(idDocuments) != "integer"))
+      stop("'idDocuments' must be a nonempty numeric vector.");
+
+   idDocuments_str <- paste(idDocuments, collapse=",");
+   query <- sprintf("SELECT IdDocument, Title, BibEntry, AlternativeId, Pages, Citations, Year, Type
+         FROM Biblio_Documents WHERE IdDocument IN (%s) ORDER BY IdDocument",
+         idDocuments_str);
+
+   res <- dbGetQuery(conn, query);
+   n <- nrow(res);
+   out <- list();
+   length(out) <- n;
+
+
+   if (n < 1) return(NULL);
+
+   query2 <- sprintf("SELECT DISTINCT IdDocument, Biblio_Authors.IdAuthor, Biblio_Authors.Name, Biblio_Authors.AuthorGroup FROM
+      Biblio_AuthorsDocuments
+      JOIN Biblio_Authors ON Biblio_Authors.IdAuthor=Biblio_AuthorsDocuments.IdAuthor
+      WHERE IdDocument IN (%s) ORDER BY IdDocument",
+      idDocuments_str);
+   res2 <- dbGetQuery(conn, query2);
+   stopifnot(nrow(res2) >= 1);
+
+
+   i <- 1;
+   k <- 1;
+   m <- nrow(res2);
+
+   while (i <= m)
+   {
+      stopifnot(res2$IdDocument[i] == res$IdDocument[k]);
+
+      j <- i+1;
+      while (j<=m && res2$IdDocument[i] == res2$IdDocument[j])
+         j <- j+1;
+
+      authors <- list();
+      length(authors) <- j-i;
+      for (u in i:(j-1))
+      {
+         authors[[u-i+1]] <- list(IdAuthor=res2[u,2], Name=res2[u,3], AuthorGroup=res2[u,4]);
+         class(authors[[u-i+1]]) <- "authorinfo";
+      }
+
+      doc <- list(IdDocument=res[k,1], Authors=authors, Title=res[k,2], BibEntry=res[k,3],
+         AlternativeId=res[k,4], Pages=res[k,5], Citations=res[k,6],
+         Year=res[k,7], Type=.lbs_DocumentType_ShortToFull(res[k,8]));
+
+      class(doc) <- "docinfo";
+
+      out[[k]] <- doc;
+
+
+      i <- j;
+      k <- k+1;
+   }
+   stopifnot(k-1 == n);
+
+
+   return(out);
 }
 
 
-#' Converts an object of type \code{docinfo} to a character string.
+#' Converts an object of class \code{docinfo} to a character string.
 #' Such an object is  returned by e.g. \code{\link{lbsGetInfoDocuments}}.
 #'
 #' A \code{docinfo} object is a list with the following components:
@@ -182,7 +178,7 @@ lbsGetInfoDocuments <- function(conn, idDocuments)
 #' \item \code{Authors} --- list of \code{authorinfo} objects (see e.g. \code{\link{as.character.authorinfo}}).
 #' \item \code{Title} --- title of the document,
 #' \item \code{BibEntry} --- bibliographic entry,
-#' \item \code{UniqueId} --- unique character identifier,
+#' \item \code{AlternativeId} --- unique character identifier,
 #' \item \code{Pages} --- number of pages,
 #' \item \code{Citations} --- number of citations,
 #' \item \code{Year} --- publication year,
@@ -190,48 +186,50 @@ lbsGetInfoDocuments <- function(conn, idDocuments)
 #' }
 #'
 #' @title Coerce a docinfo object to character string
-#' @param x a single object of type \code{docinfo}.
+#' @param x a single object of class \code{docinfo}.
 #' @param ... unused.
 #' @return A character string
 #' @export
+#' @method as.character docinfo
 #' @seealso \code{\link{lbsSearchDocuments}},
 #' \code{\link{as.character.authorinfo}}, \code{\link{print.docinfo}},\cr
 #' \code{\link{lbsGetInfoDocuments}}
 as.character.docinfo <- function(x, ...)
 {
-	ret <-            sprintf("IdDocument: %g", x$IdDocument);
-	ret <- paste(ret, sprintf("UniqueId:   %s", x$UniqueId), sep="\n");
-	ret <- paste(ret, sprintf("Title:      %s", x$Title), sep="\n");
-	ret <- paste(ret, sprintf("BibEntry:   %s", x$BibEntry), sep="\n");
-	ret <- paste(ret, sprintf("Year:       %s", x$Year), sep="\n");
-	ret <- paste(ret, sprintf("Type:       %s", x$Type), sep="\n");
-	ret <- paste(ret, sprintf("Citations:  %s", x$Citations), sep="\n");
-	ret <- paste(ret, sprintf("Authors:    %s\n",
-		paste(
-			sapply(x$Authors, function(y) paste(y$Name, y$IdAuthor, sep="/")),
-			collapse=", ")
-		), sep="\n");
-	return(ret);
+   ret <-            sprintf("IdDocument:    %g", x$IdDocument);
+   ret <- paste(ret, sprintf("AlternativeId: %s", x$AlternativeId), sep="\n");
+   ret <- paste(ret, sprintf("Title:         %s", x$Title), sep="\n");
+   ret <- paste(ret, sprintf("BibEntry:      %s", x$BibEntry), sep="\n");
+   ret <- paste(ret, sprintf("Year:          %s", x$Year), sep="\n");
+   ret <- paste(ret, sprintf("Type:          %s", x$Type), sep="\n");
+   ret <- paste(ret, sprintf("Citations:     %s", x$Citations), sep="\n");
+   ret <- paste(ret, sprintf("Authors:       %s\n",
+      paste(
+         sapply(x$Authors, function(y) paste(y$Name, y$IdAuthor, y$AuthorGroup, sep="/")),
+         collapse=", ")
+      ), sep="\n");
+   return(ret);
 }
 
-#' Prints out an object of type \code{docinfo}. Such an object is returned by e.g. \code{\link{lbsGetInfoDocuments}}.
+#' Prints out an object of class \code{docinfo}. Such an object is returned by e.g. \code{\link{lbsGetInfoDocuments}}.
 #'
 #' For more information see man page for \code{\link{as.character.docinfo}}.
 #'
 #' @title Print a docinfo object
-#' @param x an object of type \code{docinfo}.
+#' @param x an object of class \code{docinfo}.
 #' @param ... unused.
 #' @export
+#' @method print docinfo
 #' @seealso \code{\link{as.character.docinfo}}, \code{\link{lbsSearchDocuments}}, \code{\link{lbsGetInfoDocuments}}
 print.docinfo <- function(x, ...)
 {
-	cat(as.character(x));
+   cat(as.character(x));
 }
 
 
 
 
-#' Converts an object of type \code{authorinfo} to a character string.
+#' Converts an object of class \code{authorinfo} to a character string.
 #' Such an object is returned by e.g. \code{\link{lbsGetInfoAuthors}}.
 #'
 #' An \code{authorinfo} object  is a list with the following components:
@@ -241,30 +239,34 @@ print.docinfo <- function(x, ...)
 #' }
 #'
 #' @title Coerce an authorinfo object to character string
-#' @param x a single object of type \code{authorinfo}.
+#' @param x a single object of class \code{authorinfo}.
 #' @param ... unused.
 #' @return A character string
 #' @export
+#' @method as.character authorinfo
 #' @seealso \code{\link{print.authorinfo}}, \code{\link{lbsSearchAuthors}}, \code{\link{lbsGetInfoAuthors}}
 as.character.authorinfo <- function(x, ...)
 {
-	ret <-            sprintf("IdAuthor: %g",   x$IdAuthor);
-	ret <- paste(ret, sprintf("Name:     %s\n", x$Name), sep="\n");
-	return(ret);
+   ret <-            sprintf("IdAuthor:    %g",   x$IdAuthor);
+   ret <- paste(ret, sprintf("Name:        %s", x$Name), sep="\n");
+   ret <- paste(ret, sprintf("AuthorGroup: %s\n", x$AuthorGroup), sep="\n");
+   return(ret);
 }
 
-#' Prints out an object of type \code{authorinfo}. Such an object is returned by e.g. \code{\link{lbsGetInfoAuthors}}.
+#' Prints out an object of class \code{authorinfo}. Such an object is returned by e.g. \code{\link{lbsGetInfoAuthors}}.
 #'
 #' For more information see man page for \code{\link{as.character.authorinfo}}.
 #'
 #' @title Print an authorinfo object
-#' @param x an object of type \code{authorinfo}.
+#' @param x an object of class \code{authorinfo}.
 #' @param ... unused.
+#' @method print authorinfo
 #' @export
 #' @seealso \code{\link{as.character.authorinfo}}, \code{\link{lbsSearchAuthors}}, \code{\link{lbsGetInfoAuthors}}
 print.authorinfo <- function(x, ...)
 {
-	cat(as.character(x));
+   cat(as.character(x));
 }
 
 
+
